pub struct AudioBuffer {
pub data: Vec<u8>,
pub config: AudioConfig,
}Expand description
A chunk of raw audio data with its format metadata.
Fields
data: Vec<u8>Raw PCM sample data (little-endian).
config: AudioConfigAudio configuration describing the format of data.
Implementations
Sourceimpl AudioBuffer
impl AudioBuffer
Sourcepub fn new(config: AudioConfig) -> Self
pub fn new(config: AudioConfig) -> Self
Create a new empty buffer with the given config.
Sourcepub fn from_pcm(data: Vec<u8>, config: AudioConfig) -> Self
pub fn from_pcm(data: Vec<u8>, config: AudioConfig) -> Self
Create a buffer from raw PCM bytes.
Sourcepub fn duration_secs(&self) -> f64
pub fn duration_secs(&self) -> f64
Duration of the audio in seconds.
Sourcepub fn num_frames(&self) -> usize
pub fn num_frames(&self) -> usize
Number of frames in this buffer.